                <div class="card" style="min-height: 450px;">
                  <?php $i_ser = 0; ?>
                  @if(isset($data_hoteles))
                      <?php $url = route('hotel.single',$key->url).$data_hoteles['url']; ?>
                    @else
                      <?php $url = route('hotel.single',$key->url)?>
                    @endif
                  @if($key->imagenes->count() == 0) 
                    <a href="{{$url}}">
                      <img class="card-img-top" src="{{asset('img/hotel.png')}}" alt="Hotel" style="min-width: 150px !important; max-height: 150px !important;" />
                    </a>                    
                  @else
                    <a href="{{$url}}">
                      <img class="card-img-top" src="{{asset($key->imagenes[0]->img)}}" alt="Hotel" style="min-width: 150px !important; max-height: 150px !important;" />
                    </a>                    
                  @endif                
                  <div class="card-body">
                    <a href="{{route('hotel.single',$key->url)}}"><h6>{{$key->nombre}}</h6></a>
                    @if($key->servicios_principales_count() != 0)
                      <small>Servicios </small>
                      <div data-flickity='{ "cellAlign": "center", "contain": true, "pageDots":true, "wrapAround":true, "autoPlay":false, "imagesLoaded":true, "groupCells": true,"groupCells": 3,"freeScroll": true}'> 
                        <?php $i_ser = 1; $i=0; ?>
                              <?php 
                              $ser_cant = $key->servicios_principales_count();
                              if ($ser_cant >= 5) {
                                $cant=2;
                              }else{
                                $cant =  12 / $ser_cant;
                              } 
                              $data = $key->servicios_principales();
                          ?>      

                          @for($i=0; $i<($ser_cant*2); $i++)
                            <div class="col-{{$cant}}" style="padding: 0px;">
                                <img style="display: inline-block;" class="material-icons" 
                                src="{{asset($data[$i])}}" data-toggle="tooltip" data-placement="top" 
                                <?php $i++; ?>
                                title="{{$data[$i]}}">
                              </div>
                          @endfor
                      </div>
                    @endif
                    <div class="mb-1 mt-4">
                      <div>
                        <h5>
                          <small>
                            Desde
                            <strong>
                              @if(session('id_moneda')==2) Q @endif
                              @if(session('id_moneda')==1) $ @endif
                            </strong>
                            <strong>{{$key->precio_desde(session('id_moneda')) }} </strong>
                          </small>
                        </h5>
                        <div>

                          @for($e=0;$e<$key->estrellas;$e++)
                            <i class="material-icons text-warning" style="display: inline-block;">star</i>
                          @endfor                       
                        
                          <div class="bg-dark text-white" style="min-width: 50px; max-width: 50px; float: right; border-radius: 5px;">
                            <center>{{$key->promedio()}}</center>
                          </div>
                        </div>
                        @if ($key->recomendaciones->count() != 0)
                          <strong>recomendado por:</strong><br>
                            <div class="row">
                              @foreach($key->recomendaciones as $key2)
                              <div class="col">
                                <img src="{{asset($key2->empresa->logo)}}" width="100px" height="40px">
                              </div>
                              @endforeach                         
                            </div>
                        @endif  

                        @if(isset($data_hoteles))
                          <br>
                          @if($key->check_disponibilidades($data_hoteles) == 'OK')
                            <small class="text-success mb-1 mt-2">Hay habitaciones disponibles para la fecha indicada </small>                             
                          @else
                            <small class="text-danger mb-1 mt-2">{{$key->check_disponibilidades($data_hoteles)}}</small>       
                          @endif 
                        @endif              
                      </div>
                    </div>
                  </div>
                  <div class="card-footer">
                    <div class="d-flex align-items-center justify-content-between">
                        @if(isset($data_hoteles))
                          <a href="{{route('hotel.single',$key->url)}}{{$data_hoteles['url']}}">Ver más</a>
                        @else
                          <a href="{{route('hotel.single',$key->url)}}">Ver más</a>
                        @endif                         
                        <i class="material-icons text-dark">keyboard_arrow_right</i>
                    </div>
                  </div>
                </div>